@@ -76,7 +76,7 @@ pub fn table_to_string(conn: &Connection<'_>, table_name: &str, column_names: &[
 
 pub fn cursor_to_string(cursor: impl Cursor) -> String {
     let batch_size = 20;
-    let mut buffer = buffers::TextRowSet::for_cursor(batch_size, &cursor, None).unwrap();
+    let mut buffer = buffers::TextRowSet::for_cursor(batch_size, &cursor, Some(8192)).unwrap();
     let mut row_set_cursor = cursor.bind_buffer(&mut buffer).unwrap();
 
     let mut text = String::new();
